---
title: 文件
type: docs
weight: 1
prev: docs/developer-guide
next: docs/get-started
---

`PETsARD`（隱私強化技術分析、研究與開發, /pəˈtɑrd/）是一套為了促進資料生成演算法及其評估過程而設計的 Python 程式庫。

其主要功能包括描述資料集、執行各種資料集生成算法，以及對隱私保護和效用進行測量。

## 設計架構

下圖為 `PETsARD` 的實驗流程與套件結構設計。

<p align="center"><img src="/petsard/images/PETsARD_design_zhtw.png"></p>

## 版本紀錄

- [Milestone](https://github.com/nics-tw/PETsARD/releases/latest)
  - 里程碑文件包含了 `PETsARD` 最新版本的詳細資訊。
- [Release Note](https://github.com/nics-tw/petsard/releases)
  - 發佈通知提供 `PETsARD` 每個版本的變更內容。
- [CHANGELOG.md](https://github.com/nics-tw/petsard/blob/main/CHANGELOG.md)
  - 更新日誌提供 `PETsARD` 隨時間演進的所有變更。

## 開源

歡迎提交拉取請求。對於重大變更，請先開啟一個議題來討論您想做的改變。並請確保適當地更新測試。